@@ -1,5 +1,4 @@
-from main import check
+from work import check
 
 if __name__ == "main":
     check()
-
